/*
 *   kscan - a scanning program
 *   Copyright (C) 1998 Ivan Shvedunov
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#ifndef __PREFERENCES_H__
#define __PREFERENCES_H__

#include <kapp.h>
#include <qpushbt.h>
#include <qdialog.h>
#include <qlined.h>
#include <qchkbox.h>
#include <stdlib.h>

#include "scan.h"

class Preferences: public QDialog {
	Q_OBJECT
public:
	Preferences(KConfig *kc,bool *acquire_at_start,
		    int *maxdpi);
protected slots:
	void done(int);
private:
	KConfig *kconf;
	bool *p_ac;
	int *p_dpi;
	QCheckBox *ac_b,*br_b,*cn_b;
	QLineEdit *dpi_e;
};

#endif
